#!/bin/bash

OFED_PREFIX=/usr/local

IBV_DEVINFO=${OFED_PREFIX}/bin/ibv_devinfo
OPENSM=${OFED_PREFIX}/bin/opensm
GREP=/bin/grep
CUT=/bin/cut

if [[ "$1" == "--server" ]]; then
	IS_SERVER=1
	echo "Server side, The SM wil be executed on this side"
elif [[ "$1" == "--client" ]]; then
	IS_SERVER=0
	echo "Client side"
else
	echo "Syntax: $0 <--server | --client>"
	exit 1
fi

function execute_test()
{
	echo "Test case was started"

	# restart the driver
	echo "restarting driver"
	/etc/init.d/openibd restart

	# calc how many MC groups will be used in this iteration
	let "num_of_grp = `${IBV_DEVINFO} -v | ${GREP} max_mcast_grp | ${CUT} -d':' -f2` - $1"
	echo "Now trying to use num_of_grp = $num_of_grp"

	# start the process that allocate the mcgs	
	./alloc_mcast --device=mthca0 --num_of_mcast=${num_of_grp} --sleep=60 &
	PID1=$!

	# sleep for a while to let all the mcgs be allocated
	sleep 20

	if [[ "$IS_SERVER" == "1" ]]; then
		# start the sm
		echo "Going to execute the SM"
		${OPENSM} &
		PID2=$!

		sleep 10
	
		#kill the SM 
		echo "Going to kill the SM"
		kill -9 $PID2
	fi

	wait $PID1

	echo "Test case was ended"
}

echo "Test was started"

execute_test 1
execute_test 2
execute_test 3

echo "Test was ended"
